Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5)

Unified Diff: src/gpu/GrGpu.h

Issue 1133123009: rename GrDrawTargetCaps to GrCaps (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: fix gypi filename Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/gpu/GrDrawTargetCaps.h ('k') | src/gpu/GrOvalRenderer.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/gpu/GrGpu.h
diff --git a/src/gpu/GrGpu.h b/src/gpu/GrGpu.h
index f2ad10f41714c6faf9beb947eed234025b20677e..6e8dc43f75ac9c8faa19aa487468c6b545891997 100644
--- a/src/gpu/GrGpu.h
+++ b/src/gpu/GrGpu.h
@@ -44,7 +44,7 @@ public:
/**
* Gets the capabilities of the draw target.
*/
- const GrDrawTargetCaps* caps() const { return fCaps.get(); }
+ const GrCaps* caps() const { return fCaps.get(); }
GrPathRendering* pathRendering() { return fPathRendering.get(); }
@@ -66,7 +66,7 @@ public:
* Creates a texture object. If kRenderTarget_GrSurfaceFlag the texture can
* be used as a render target by calling GrTexture::asRenderTarget(). Not all
* pixel configs can be used as render targets. Support for configs as textures
* or render targets can be checked using GrDrawTargetCaps.
*
* @param desc describes the texture to be created.
* @param budgeted does this texture count against the resource cache budget?
@@ -403,7 +403,7 @@ protected:
Stats fStats;
SkAutoTDelete<GrPathRendering> fPathRendering;
// Subclass must initialize this in its constructor.
- SkAutoTUnref<const GrDrawTargetCaps> fCaps;
+ SkAutoTUnref<const GrCaps> fCaps;
private:
// called when the 3D context state is unknown. Subclass should emit any
« no previous file with comments | « src/gpu/GrDrawTargetCaps.h ('k') | src/gpu/GrOvalRenderer.cpp » ('j') | no next file with comments »
@@ -66,7 +66,7 @@ public:
* be used as a render target by calling GrTexture::asRenderTarget(). Not all
* pixel configs can be used as render targets. Support for configs as textures
- * or render targets can be checked using GrDrawTargetCaps.
+ * or render targets can be checked using GrCaps.
*
* @param desc describes the texture to be created.

Powered by Google App Engine
This is Rietveld 408576698